import '@zhinjs/plugin-console';
import { Awaitable, Context, Zhin, Schema } from 'zhin';
import { DataService } from '@zhinjs/plugin-console';
import { UserTable } from '@zhinjs/plugin-database';
declare module '@zhinjs/plugin-database' {
    namespace UserTable {
        interface Types {
            password: string;
            token: string;
            expire: number;
        }
    }
}
declare module '@zhinjs/plugin-console' {
    interface SocketHandle {
        user?: UserAuth;
    }
    namespace Console {
        interface Services {
            user: AuthService;
        }
    }
    interface Events {
        'login/captcha'(this: SocketHandle, user_id: number): Awaitable<UserLogin>;
        'login/password'(this: SocketHandle, user_id: number, password: string): void;
        'login/token'(this: SocketHandle, user_id: number, token: string): void;
        'user/update'(this: SocketHandle, data: UserUpdate): void;
        'user/logout'(this: SocketHandle): void;
    }
}
export type UserAuth = Pick<UserTable.Types, 'user_id' | 'name' | 'authority' | 'token' | 'expire'>;
export type UserLogin = Pick<UserTable.Types, 'user_id' | 'name' | 'token' | 'expire'>;
export type UserUpdate = Partial<Pick<UserTable.Types, 'name' | 'password'>>;
export class AuthService extends DataService<UserAuth> {
    private config;
    static using: readonly ["console", "database"];
    constructor(ctx: Context, config: AuthService.Config);
    init(): Promise<void>;
    initLogin(): void;
}
declare namespace AuthService {
    interface Config {
        authTokenExpire?: number;
        loginTokenExpire?: number;
    }
}
declare module '@zhinjs/plugin-console' {
    namespace Console {
        interface Services {
            config: ConfigService;
        }
    }
    interface Events {
        'config/update'(this: SocketHandle, options: Zhin.Options): Awaitable<string>;
        'config'(this: SocketHandle): void;
    }
}
export class ConfigService extends DataService<{}> {
    constructor(ctx: Context);
    startListen(): void;
}
export const using: string[];
export const Config: Schema<{
    authTokenExpire?: number;
    loginTokenExpire?: number;
} & import("zhin").Dict<any, string>, {
    authTokenExpire: number;
    loginTokenExpire: number;
} & import("zhin").Dict<any, string>>;
export function install(ctx: Context): void;
